pub struct Polygon {
pub vertices: Vec<Point>,
}Expand description
A polygon represented by an ordered sequence of boundary vertices.
Vertices must occur consecutively around the polygon boundary, either clockwise or counter-clockwise. The final edge back to the first vertex is implicit, so the first vertex should not be repeated at the end.
A polygon can be concave or self-intersecting, but some algorithms may return degenerate boundaries for those inputs. This type represents one boundary only; it cannot represent holes or multiple disconnected polygons.
Fields
vertices: Vec<Point>Vertices of the polygon.
Implementations